/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"

#define TABLE_LENGTH 128
#define DMA_BYTES_PER_BURST 1
#define DMA_REQUEST_PER_BURST 1

/* This table stores the 128 points in Flash for smoother sine wave generation */

const uint8 sineTable2[TABLE_LENGTH] = 
{
	128, 134, 140, 147, 153, 159, 165, 171,
	177, 183, 188, 194, 199, 204, 209, 214,
	218, 223, 227, 231, 234, 238, 241, 244,
	246, 248, 250, 252, 253, 254, 255, 255,
	255, 255, 255, 254, 253, 252, 250, 248,
	246, 244, 241, 238, 234, 231, 227, 223,
	218, 214, 209, 204, 199, 194, 188, 183, 
	177, 171, 165, 159, 153, 147, 140, 134, 
	128, 122, 115, 109, 103,  97,  91,  85,
	 79,  73,  68,  62,  57,  52,  47,  42,
	 37,  33,  29,  25,  22,  18,  15,  12,
	 10,   7,   6,   4,   2,   1,   1,   0,
	  0,   0,   1,   1,   2,   4,   6,   7,
	 10,  12,  15,  18,  22,  25,  29,  33,
	 37,  42,  47,  52,  57,  62,  68,  73,
	 79,  85,  91,  97, 103, 109, 115, 122
};	

const uint8 sineTable[TABLE_LENGTH] = 
{
	255, 255, 255, 255, 255, 255, 255, 255,
	255, 250, 240, 230, 220, 210, 200, 190,
	180, 170, 160, 150, 140, 130, 120, 110,
	100, 90, 80, 70, 60, 50, 40, 30,
	190, 190, 190, 190, 190, 190, 190, 190,
	190, 190, 190, 190, 190, 190, 190, 190,
	190, 190, 190, 190, 190, 190, 190, 190, 
	190, 190, 190, 190, 190, 190, 190, 190, 
	190, 190, 190, 190, 190, 190, 190, 190,
	 190, 190, 190, 190, 190, 190, 190, 190,
	180, 170, 160, 150, 140, 130, 120, 110,
	 180, 170, 160, 150, 140, 130, 120, 110,
	 100, 90, 80, 70, 60, 50, 40, 30,
	 100, 90, 80, 70, 60, 50, 40, 30,
	 20, 10, 10, 10, 10, 10, 10, 10,
	 20, 10, 10, 10, 10, 10, 10, 10
};	

const uint8 highTable[5]=
{255,255,255,255,255};


#define DMA_SRC_BASE (&sineTable[0])
#define DMA_DST_BASE (CYDEV_PERIPH_BASE)
/* Variable declarations for DMA . 
* These variables are defined as global variables to avoid "may be used before being set" warning 
* issued by the PSoC 5 compilers  MDK/RVDS.In this case these variables are automatically initialized to zero */
uint8 DMA_Chan;               /* The DMA Channel */
uint8 DMA_TD[2];	          /* The DMA Transaction Descriptor (TD) */  	

CY_ISR_PROTO(isr_1_routine);

int main(void)
{
    /* Step1 : DmaInitialize - Initialize the DMA channel
	 * Bytes per burst = 1, (8 bit data transferred to VDAC one at a time)
	 * Request per burst = 1 (this will cause transfer of the bytes only with every new request)
	 * High byte of source address = Upper 16 bits of Flash Base address for PSoC 3,
	                               = HI16(&sineTable) for PSoC 5
     * High byte of destination address =  Upper 16 bits of peripheral base address */
    DMA_Chan = DMA_DmaInitialize(DMA_BYTES_PER_BURST, DMA_REQUEST_PER_BURST, HI16(DMA_SRC_BASE), HI16(DMA_DST_BASE) );
	
	
    /* Step2 :CyDmaTdAllocate - Allocate TD */
    DMA_TD[0] = CyDmaTdAllocate();  								 
    DMA_TD[1] = CyDmaTdAllocate();
    
    /* Step3 :CyDmaTdSetConfiguration - Configures the TD:
	 * tdHandle = DMA_TD[0] - TD handle previously returned by CyDmaTdAlloc()
	 * Transfer count = table_length (number of bytes to transfer for a sine wave)
	 * Next Td = DMA_TD[0] ; loop back to the same TD to generate a continous sien wave 
	 * Configuration = The source address is incremented after every burst transfer
	 */
	CyDmaTdSetConfiguration(DMA_TD[0], TABLE_LENGTH, DMA_TD[1], CY_DMA_TD_TERMIN_EN | CY_DMA_TD_INC_SRC_ADR);
CyDmaTdSetConfiguration(DMA_TD[1], 5, DMA_TD[0], CY_DMA_TD_TERMIN_EN | CY_DMA_TD_INC_SRC_ADR);

    //CyDmaTdSetConfiguration(DMA_TD[0], TABLE_LENGTH, DMA_TD[0], CY_DMA_TD_TERMIN_EN); 	 
	//CyDmaTdSetConfiguration(DMA_TD[0], TABLE_LENGTH, CY_DMA_DISABLE_TD, CY_DMA_TD_TERMIN_EN | DMA__TD_TERMOUT_EN | CY_DMA_TD_INC_SRC_ADR);
    /* Step 4 : CyDmaTdSetAddress - Configure the lower 16 bit source and destination addresses 
	 * Source address = Lower 16 bits of sineTable array
	 * Destination address = Lower 16 bits of VDAC8_Data_PTR register */
    CyDmaTdSetAddress(DMA_TD[0], LO16((uint32)sineTable), LO16((uint32)VDAC8_Data_PTR) );
    CyDmaTdSetAddress(DMA_TD[1], LO16((uint32)highTable), LO16((uint32)VDAC8_Data_PTR) );
    
    
    /* Step 5: Map the TD to the DMA Channel */
    CyDmaChSetInitialTd(DMA_Chan, DMA_TD[0]); 	
	
    
    /* Step 6: Enable the DMA channel */
    CyDmaChEnable(DMA_Chan, 1); 	
    
    CyGlobalIntEnable; /* Enable global interrupts. */

    /* Place your initialization/startup code here (e.g. MyInst_Start()) */
    VDAC8_Start();
    PWM_1_Start();
    
    isr_1_ClearPending();
    isr_1_StartEx(isr_1_routine);
   
    
    for(;;)
    {
        /* Place your application code here. */
    }
}

CY_ISR(isr_1_routine)
{
 //CyDmaChSetRequest(   DMA_Chan, CY_DMA_CPU_TERM_TD);
}
/* [] END OF FILE */
